Home
last modified time | relevance | path

Searched refs:operator (Results 1 – 25 of 1660) sorted by relevance

12345678910>>...67

/freebsd-13.1/contrib/byacc/test/btyacc/
H A Dquote_calc4-s.output41 "SUB-operator" shift 3
62 "SUB-operator" shift 3
83 "ADD-operator" reduce 15
84 "SUB-operator" reduce 15
85 "MUL-operator" reduce 15
86 "DIV-operator" reduce 15
96 "SUB-operator" shift 3
123 "ADD-operator" shift 16
124 "SUB-operator" shift 17
125 "MUL-operator" shift 18
[all …]
H A Dquote_calc4.output41 "SUB-operator" shift 3
62 "SUB-operator" shift 3
83 "ADD-operator" reduce 15
84 "SUB-operator" reduce 15
85 "MUL-operator" reduce 15
86 "DIV-operator" reduce 15
96 "SUB-operator" shift 3
123 "ADD-operator" shift 16
124 "SUB-operator" shift 17
125 "MUL-operator" shift 18
[all …]
/freebsd-13.1/contrib/byacc/test/yacc/
H A Dquote_calc4-s.output41 "SUB-operator" shift 3
62 "SUB-operator" shift 3
83 "ADD-operator" reduce 15
84 "SUB-operator" reduce 15
85 "MUL-operator" reduce 15
86 "DIV-operator" reduce 15
96 "SUB-operator" shift 3
123 "ADD-operator" shift 16
124 "SUB-operator" shift 17
125 "MUL-operator" shift 18
[all …]
H A Dquote_calc4.output41 "SUB-operator" shift 3
62 "SUB-operator" shift 3
83 "ADD-operator" reduce 15
84 "SUB-operator" reduce 15
85 "MUL-operator" reduce 15
86 "DIV-operator" reduce 15
96 "SUB-operator" shift 3
123 "ADD-operator" shift 16
124 "SUB-operator" shift 17
125 "MUL-operator" shift 18
[all …]
/freebsd-13.1/contrib/llvm-project/llvm/include/llvm/IR/
H A DDiagnosticPrinter.h36 virtual DiagnosticPrinter &operator<<(char C) = 0;
43 virtual DiagnosticPrinter &operator<<(long N) = 0;
45 virtual DiagnosticPrinter &operator<<(long long N) = 0;
48 virtual DiagnosticPrinter &operator<<(int N) = 0;
49 virtual DiagnosticPrinter &operator<<(double N) = 0;
69 DiagnosticPrinter &operator<<(char C) override;
71 DiagnosticPrinter &operator<<(signed char C) override;
76 DiagnosticPrinter &operator<<(long N) override;
78 DiagnosticPrinter &operator<<(long long N) override;
81 DiagnosticPrinter &operator<<(int N) override;
[all …]
H A DValueHandle.h69 Value *operator=(Value *RHS) {
92 Value &operator*() const {
153 Value *operator=(Value *RHS) {
160 operator Value*() const {
213 Value *operator=(Value *RHS) {
220 operator Value*() const {
293 operator ValueTy*() const {
363 operator ValueTy*() const {
391 ValueHandleBase::operator=(P);
399 operator Value*() const {
[all …]
/freebsd-13.1/contrib/llvm-project/llvm/include/llvm/ExecutionEngine/Orc/
H A DDebugUtils.h33 raw_ostream &operator<<(raw_ostream &OS, const SymbolStringPtr &Sym);
36 raw_ostream &operator<<(raw_ostream &OS, const SymbolNameSet &Symbols);
45 raw_ostream &operator<<(raw_ostream &OS, const JITSymbolFlags &Flags);
57 raw_ostream &operator<<(raw_ostream &OS, const SymbolMap &Symbols);
60 raw_ostream &operator<<(raw_ostream &OS,
70 raw_ostream &operator<<(raw_ostream &OS,
77 raw_ostream &operator<<(raw_ostream &OS, const LookupKind &K);
86 raw_ostream &operator<<(raw_ostream &OS,
93 raw_ostream &operator<<(raw_ostream &OS, const SymbolState &S);
96 raw_ostream &operator<<(raw_ostream &OS, const LookupKind &K);
[all …]
/freebsd-13.1/contrib/llvm-project/llvm/include/llvm/ADT/
H A DAPSInt.h63 APSInt &operator=(APInt RHS) {
65 APInt::operator=(std::move(RHS));
69 APSInt &operator=(uint64_t RHS) {
71 APInt::operator=(RHS);
139 APSInt& operator>>=(unsigned Amt) {
201 APSInt& operator++() {
205 APSInt& operator--() {
209 APSInt operator++(int) {
212 APSInt operator--(int) {
215 APSInt operator-() const {
[all …]
H A Diterator.h124 DerivedT &operator++() {
129 DerivedT operator++(int) {
134 DerivedT &operator--() {
140 DerivedT operator--(int) {
175 PointerT operator->() { return &static_cast<DerivedT *>(this)->operator*(); }
176 PointerT operator->() const {
245 using BaseT::operator-;
255 using BaseT::operator++;
256 DerivedT &operator++() {
260 using BaseT::operator--;
[all …]
H A DOptional.h116 OptionalStorage &operator=(T const &y) {
125 OptionalStorage &operator=(T &&y) {
149 OptionalStorage &operator=(OptionalStorage &&other) {
216 OptionalStorage &operator=(T const &y) {
225 OptionalStorage &operator=(T &&y) {
257 Optional &operator=(T &&y) {
261 Optional &operator=(Optional &&O) = default; variable
272 Optional &operator=(const T &y) {
276 Optional &operator=(const Optional &O) = default; variable
290 T *operator->() { return getPointer(); }
[all …]
H A DStatistic.h70 operator unsigned() const { return getValue(); }
72 const TrackingStatistic &operator=(unsigned Val) {
77 const TrackingStatistic &operator++() {
82 unsigned operator++(int) {
87 const TrackingStatistic &operator--() {
92 unsigned operator--(int) {
97 const TrackingStatistic &operator+=(unsigned V) {
104 const TrackingStatistic &operator-=(unsigned V) {
139 operator unsigned() const { return 0; }
145 unsigned operator++(int) { return 0; }
[all …]
/freebsd-13.1/contrib/llvm-project/llvm/lib/Target/Hexagon/
H A DHexagonBlockRanges.h39 bool operator<(RegisterRef R) const {
61 operator unsigned() const;
62 bool operator== (unsigned x) const;
63 bool operator== (IndexType Idx) const;
64 bool operator!= (unsigned x) const;
65 bool operator!= (IndexType Idx) const;
66 IndexType operator++ ();
67 bool operator< (unsigned Idx) const;
68 bool operator< (IndexType Idx) const;
210 return operator< (IndexType(Idx));
[all …]
/freebsd-13.1/contrib/llvm-project/lldb/include/lldb/Utility/
H A DScalar.h125 Scalar &operator+=(Scalar rhs);
128 Scalar &operator&=(const Scalar &rhs);
236 const Scalar operator-(Scalar lhs, Scalar rhs);
237 const Scalar operator/(Scalar lhs, Scalar rhs);
238 const Scalar operator*(Scalar lhs, Scalar rhs);
239 const Scalar operator&(Scalar lhs, Scalar rhs);
240 const Scalar operator|(Scalar lhs, Scalar rhs);
241 const Scalar operator%(Scalar lhs, Scalar rhs);
242 const Scalar operator^(Scalar lhs, Scalar rhs);
245 bool operator==(Scalar lhs, Scalar rhs);
[all …]
H A DIterable.h50 bool operator==(const AdaptedConstIterator &rhs) {
54 bool operator!=(const AdaptedConstIterator &rhs) {
59 E operator*() { return (*A)(m_iter); }
61 E operator->() { return (*A)(m_iter); }
69 AdaptedConstIterator &operator++() {
75 AdaptedConstIterator &operator--() {
115 operator+(typename C1::const_iterator::difference_type,
120 operator-(AdaptedConstIterator<C1, E1, A1> &,
132 AdaptedConstIterator<C, E, A> operator+(
136 return rhs.operator+(offset);
[all …]
/freebsd-13.1/contrib/llvm-project/llvm/include/llvm/Support/
H A DInstructionCost.h111 InstructionCost &operator+=(const CostType RHS) {
128 InstructionCost &operator-=(const CostType RHS) {
168 InstructionCost &operator++() {
173 InstructionCost operator++(int) {
179 InstructionCost &operator--() {
184 InstructionCost operator--(int) {
209 bool operator==(const CostType RHS) const {
222 bool operator<(const CostType RHS) const {
227 bool operator>(const CostType RHS) const {
232 bool operator<=(const CostType RHS) const {
[all …]
H A DAlignment.h46 friend bool operator==(Align Lhs, Align Rhs);
47 friend bool operator!=(Align Lhs, Align Rhs);
48 friend bool operator<=(Align Lhs, Align Rhs);
49 friend bool operator>=(Align Lhs, Align Rhs);
50 friend bool operator<(Align Lhs, Align Rhs);
51 friend bool operator>(Align Lhs, Align Rhs);
74 Align &operator=(Align &&Other) = default; member
282 inline bool operator==(Align Lhs, Align Rhs) {
285 inline bool operator!=(Align Lhs, Align Rhs) {
294 inline bool operator<(Align Lhs, Align Rhs) {
[all …]
H A DBlockFrequency.h39 BlockFrequency &operator*=(BranchProbability Prob);
44 BlockFrequency &operator/=(BranchProbability Prob);
48 BlockFrequency &operator+=(BlockFrequency Freq);
49 BlockFrequency operator+(BlockFrequency Freq) const;
52 BlockFrequency &operator-=(BlockFrequency Freq);
56 BlockFrequency &operator>>=(const unsigned count);
58 bool operator<(BlockFrequency RHS) const {
62 bool operator<=(BlockFrequency RHS) const {
66 bool operator>(BlockFrequency RHS) const {
70 bool operator>=(BlockFrequency RHS) const {
[all …]
/freebsd-13.1/contrib/llvm-project/libcxx/include/
H A Dchrono537 operator/(const year& y, int m) noexcept;
541 operator/(const month& m, int d) noexcept;
543 operator/(int m, const day& d) noexcept;
547 operator/(const day& d, int m) noexcept;
551 operator/(int m, last_spec) noexcept;
555 operator/(last_spec, int m) noexcept;
702 bool operator==(const leap& x, const leap& y);
703 bool operator!=(const leap& x, const leap& y);
704 bool operator< (const leap& x, const leap& y);
705 bool operator> (const leap& x, const leap& y);
[all …]
H A Dcompare76 constexpr operator partial_ordering() const noexcept;
79 friend constexpr bool operator==(weak_ordering v, unspecified) noexcept;
81 friend constexpr bool operator< (weak_ordering v, unspecified) noexcept;
82 friend constexpr bool operator> (weak_ordering v, unspecified) noexcept;
83 friend constexpr bool operator<=(weak_ordering v, unspecified) noexcept;
84 friend constexpr bool operator>=(weak_ordering v, unspecified) noexcept;
103 constexpr operator partial_ordering() const noexcept;
104 constexpr operator weak_ordering() const noexcept;
260 constexpr operator partial_ordering() const noexcept {
335 constexpr operator partial_ordering() const noexcept {
[all …]
H A Dnew25 bad_alloc& operator=(const bad_alloc&) noexcept;
55 void* operator new(std::size_t size, std::align_val_t alignment,
60 void operator delete(void* ptr, std::size_t size,
63 void operator delete(void* ptr, std:align_val_t alignment,
67 void* operator new[](std::size_t size,
74 void operator delete[](void* ptr,
76 void operator delete[](void* ptr, std::size_t size,
84 void operator delete (void* ptr, void*) noexcept;
85 void operator delete[](void* ptr, void*) noexcept;
237 return ::operator new(__args...);
[all …]
/freebsd-13.1/contrib/llvm-project/clang/include/clang/AST/
H A DCharUnits.h68 CharUnits& operator+= (const CharUnits &Other) {
72 CharUnits& operator++ () {
76 CharUnits operator++ (int) {
83 CharUnits& operator-- () {
87 CharUnits operator-- (int) {
142 CharUnits operator* (QuantityType N) const {
145 CharUnits &operator*= (QuantityType N) {
149 CharUnits operator/ (QuantityType N) const {
152 CharUnits &operator/= (QuantityType N) {
159 CharUnits operator% (QuantityType N) const {
[all …]
/freebsd-13.1/contrib/llvm-project/llvm/include/llvm/DebugInfo/PDB/
H A DPDBExtras.h25 raw_ostream &operator<<(raw_ostream &OS, const PDB_VariantType &Value);
26 raw_ostream &operator<<(raw_ostream &OS, const PDB_CallingConv &Conv);
27 raw_ostream &operator<<(raw_ostream &OS, const PDB_BuiltinType &Type);
28 raw_ostream &operator<<(raw_ostream &OS, const PDB_DataKind &Data);
29 raw_ostream &operator<<(raw_ostream &OS,
31 raw_ostream &operator<<(raw_ostream &OS, const PDB_LocType &Loc);
34 raw_ostream &operator<<(raw_ostream &OS, const PDB_Lang &Lang);
35 raw_ostream &operator<<(raw_ostream &OS, const PDB_SymType &Tag);
37 raw_ostream &operator<<(raw_ostream &OS, const PDB_UdtType &Type);
40 raw_ostream &operator<<(raw_ostream &OS, const Variant &Value);
[all …]
/freebsd-13.1/contrib/llvm-project/lldb/include/lldb/Host/
H A DSocketAddress.h51 const SocketAddress &operator=(const struct addrinfo *addr_info); variable
53 const SocketAddress &operator=(const struct sockaddr &s); variable
55 const SocketAddress &operator=(const struct sockaddr_in &s); variable
57 const SocketAddress &operator=(const struct sockaddr_in6 &s); variable
59 const SocketAddress &operator=(const struct sockaddr_storage &s); variable
61 bool operator==(const SocketAddress &rhs) const;
62 bool operator!=(const SocketAddress &rhs) const;
154 operator struct sockaddr *() { return &m_socket_addr.sa; }
158 operator struct sockaddr_in *() { return &m_socket_addr.sa_ipv4; }
164 operator const struct sockaddr_in6 *() const {
[all …]
/freebsd-13.1/contrib/googletest/googletest/include/gtest/
H A Dgtest-message.h112 inline Message& operator <<(const T& value) {
119 inline Message& operator <<(const T& val) {
134 using ::operator <<;
169 Message& operator <<(BasicNarrowIoManip val) {
175 Message& operator <<(bool b) {
181 Message& operator <<(const wchar_t* wide_c_str);
182 Message& operator <<(wchar_t* wide_c_str);
187 Message& operator <<(const ::std::wstring& wstr);
193 Message& operator <<(const ::wstring& wstr);
221 using ::operator <<; in StreamHelper()
[all …]
/freebsd-13.1/contrib/llvm-project/clang/lib/Headers/cuda_wrappers/
H A Dnew52 return ::operator new(size);
56 return ::operator new(size);
60 return ::operator new(size);
68 __device__ inline void operator delete(void *ptr,
70 ::operator delete(ptr);
74 ::operator delete(ptr);
76 __device__ inline void operator delete[](void *ptr,
78 ::operator delete(ptr);
83 __device__ inline void operator delete(void *ptr,
85 ::operator delete(ptr);
[all …]

12345678910>>...67